﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;

namespace ComboSelection
{
    public class MainWindowViewModel : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        private ObservableCollection<Species> _species;
        public ObservableCollection<Species> Species
        {
            get { return _species; }
            set
            {
                if (_species != value)
                {
                    _species = value;
                    OnPropertyChanged("Species");
                }
            }
        }

        private List<string> _speciesNames;
        public List<string> SpeciesNames
        {
            get { return _speciesNames; }
            set
            {
                if (_speciesNames != value)
                {
                    _speciesNames = value;
                    OnPropertyChanged("SpeciesNames");
                }
            }
        }



        private object[] _selectedSpecies;
        public object[] SelectedSpecies
        {
            get { return _selectedSpecies; }
            set
            {
                if (_selectedSpecies != value)
                {
                    _selectedSpecies = value;
                    OnPropertyChanged("SelectedSpecies");

                    if (_selectedSpecies != null && _selectedSpecies.Length > 0)
                        CurrentSpecies = _selectedSpecies[0] as Species;
                }
            }
        }

        private Species _currentSpecies;
        public Species CurrentSpecies
        {
            get { return _currentSpecies; }
            set
            {
                if (_currentSpecies != value)
                {
                    _currentSpecies = value;
                    OnPropertyChanged("CurrentSpecies");
                }
            }
        }

        private DelegateCommand _submitCommand;
        public DelegateCommand SubmitCommand
        {
            get { return _submitCommand; }
            set
            {
                if (_submitCommand != value)
                {
                    _submitCommand = value;
                    OnPropertyChanged("SubmitCommand");
                }
            }
        }

        private DelegateCommand _clearCommand;
        public DelegateCommand ClearCommand
        {
            get { return _clearCommand; }
            set
            {
                if (_clearCommand != value)
                {
                    _clearCommand = value;
                    OnPropertyChanged("ClearCommand");
                }
            }
        }
        
        public MainWindowViewModel()
        {
            SubmitCommand = new DelegateCommand(OnSubmitClicked);
            ClearCommand = new DelegateCommand(OnClearClicked);

            LoadSpecies();

            CurrentSpecies = new Species();
        }

        void LoadSpecies()
        {
            Species = new ObservableCollection<Species>();
            Species.Add(new Species { Name = "Tigers", Number = 1 });
            Species.Add(new Species { Name = "Elephants", Number = 2 });

            SpeciesNames = new List<string>();
            SpeciesNames.Add("Tigers");
            SpeciesNames.Add("Elephants");
            SpeciesNames.Add("Zebras");
            SpeciesNames.Add("Penguins");
            SpeciesNames.Add("Hawks");
            SpeciesNames.Add("Hippos");
        }

        private void OnSubmitClicked()
        {
            if (CurrentSpecies != null)
            {
                Species.Add(CurrentSpecies);

                CurrentSpecies = new Species();
            }
        }

        private void OnClearClicked()
        {
            CurrentSpecies = new Species();
        }
    }

    public class Species : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        private string _name;
        public string Name
        {
            get { return _name; }
            set
            {
                if (_name != value)
                {
                    _name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        private int _number;
        public int Number
        {
            get { return _number; }
            set
            {
                if (_number != value)
                {
                    _number = value;
                    OnPropertyChanged("Number");
                }
            }
        }
    }
}
